Motor API
=========

.. important:: This page describes using Motor with Tornado. Beginning in
  version 0.5 Motor can also integrate with asyncio instead of Tornado. The
  documentation is not yet updated for Motor's asyncio integration.

.. seealso:: :doc:`../tutorial-tornado`

.. toctree::

    motor_client
    motor_replica_set_client
    motor_database
    motor_collection
    motor_cursor
    gridfs
    web
